(function (global, factory) {
	typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('@angular/common')) :
	typeof define === 'function' && define.amd ? define(['exports', '@angular/core', '@angular/common'], factory) :
	(factory((global['ngx-editor'] = {}),global.ng.core,global.ng.common));
}(this, (function (exports,core,common) { 'use strict';

var ngxEditorConfig = {
    editable: true,
    spellcheck: true,
    height: 'auto',
    minHeight: '0',
    width: 'auto',
    minWidth: '0',
    translate: 'yes',
    placeholder: 'Enter text here...',
    toolbar: [
        ['bold', 'italic', 'underline', 'strikeThrough', 'superscript', 'subscript'],
        ['justifyLeft', 'justifyCenter', 'justifyRight', 'justifyFull', 'indent', 'outdent'],
        ['cut', 'copy', 'delete', 'removeFormat', 'undo', 'redo'],
        ['paragraph', 'blockquote', 'removeBlockquote', 'horizontalLine', 'orderedList', 'unorderedList']
    ]
};
/**
 * @param {?} value
 * @param {?} toolbar
 * @return {?}
 */
function canEnableToolbarOptions(value, toolbar) {
    if (value) {
        if (toolbar['length'] === 0) {
            return true;
        }
        else {
            return toolbar.find(function (array) {
                return array.includes(value);
            });
        }
    }
    else {
        return false;
    }
}
var NgxEditorComponent = /** @class */ (function () {
    function NgxEditorComponent() {
        this.htmlChange = new core.EventEmitter();
    }
    Object.defineProperty(NgxEditorComponent.prototype, "resizer", {
        /**
         * @return {?}
         */
        get: function () {
            return this._resizer || 'stack';
        },
        /**
         * @param {?} value
         * @return {?}
         */
        set: function (value) {
            console.log(value);
            if (value === 'basic') {
                this._resizer = value;
            }
            else {
                this._resizer = 'stack';
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NgxEditorComponent.prototype, "config", {
        /**
         * @return {?}
         */
        get: function () {
            return this._config || ngxEditorConfig;
        },
        /**
         * @param {?} value
         * @return {?}
         */
        set: function (value) {
            for (var /** @type {?} */ i in ngxEditorConfig) {
                if (i) {
                    if (this[i]) {
                        value[i] = this[i];
                    }
                    if (!value.hasOwnProperty(i)) {
                        value[i] = ngxEditorConfig[i];
                    }
                }
            }
            this._config = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NgxEditorComponent.prototype, "html", {
        /**
         * @return {?}
         */
        get: function () {
            return this._html;
        },
        /**
         * @param {?} value
         * @return {?}
         */
        set: function (value) {
            this._html = value;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @param {?} value
     * @return {?}
     */
    NgxEditorComponent.prototype.htmlContentChange = function (value) {
        if (value === '<br>') {
            this.htmlChange.emit('');
        }
        else {
            this.htmlChange.emit(value);
        }
    };
    /**
     * @param {?} commandName
     * @return {?}
     */
    NgxEditorComponent.prototype.executeCommand = function (commandName) {
        var /** @type {?} */ isExecuted = document.execCommand(commandName, false, null);
    };
    /**
     * @return {?}
     */
    NgxEditorComponent.prototype.blockQuote = function () {
        document.execCommand('formatBlock', false, '<blockquote>');
    };
    /**
     * @return {?}
     */
    NgxEditorComponent.prototype.removeQuote = function () {
        document.execCommand('formatBlock', false, 'div');
    };
    /**
     * @param {?} value
     * @return {?}
     */
    NgxEditorComponent.prototype.canEnableToolbarOptions = function (value) {
        return canEnableToolbarOptions(value, this.config['toolbar']);
    };
    /**
     * @param {?} offsetY
     * @return {?}
     */
    NgxEditorComponent.prototype.resizeTextArea = function (offsetY) {
        var /** @type {?} */ newHeight = parseInt(this.height);
        newHeight += offsetY;
        this.height = newHeight + 'px';
        this.textArea.nativeElement.style.height = this.height;
    };
    /**
     * @return {?}
     */
    NgxEditorComponent.prototype.canResize = function () {
        if (this.resizer === 'basic') {
            return 'vertical';
        }
        return false;
    };
    /**
     * @return {?}
     */
    NgxEditorComponent.prototype.ngOnInit = function () {
        this.textArea.nativeElement.innerHTML = this.html || '';
        this.height = this.height || this.textArea.nativeElement.offsetHeight;
    };
    return NgxEditorComponent;
}());
NgxEditorComponent.decorators = [
    { type: core.Component, args: [{
                selector: 'app-ngx-editor',
                template: "\n    <div class=\"ngx-editor\" id=\"ngxEditor\" [style.width]=\"config['width']\" [style.minWidth]=\"config['minWidth']\">\n      <div class=\"ngx-toolbar\">\n        <div class=\"ngx-toolbar-set\">\n          <button class=\"ngx-editor-button\" *ngIf=\"canEnableToolbarOptions('bold')\" (click)=\"executeCommand('bold')\" title=\"Bold\">\n            <i class=\"fa fa-bold\" aria-hidden=\"true\"></i>\n          </button>\n          <button class=\"ngx-editor-button\" *ngIf=\"canEnableToolbarOptions('italic')\" (click)=\"executeCommand('italic')\" title=\"Italic\">\n            <i class=\"fa fa-italic\" aria-hidden=\"true\"></i>\n          </button>\n          <button class=\"ngx-editor-button\" *ngIf=\"canEnableToolbarOptions('underline')\" (click)=\"executeCommand('underline')\" title=\"Underline\">\n            <i class=\"fa fa-underline\" aria-hidden=\"true\"></i>\n          </button>\n          <button class=\"ngx-editor-button\" *ngIf=\"canEnableToolbarOptions('strikeThrough')\" (click)=\"executeCommand('strikeThrough')\"\n            title=\"Strikethrough\">\n            <i class=\"fa fa-strikethrough\" aria-hidden=\"true\"></i>\n          </button>\n          <button class=\"ngx-editor-button\" *ngIf=\"canEnableToolbarOptions('superscript')\" (click)=\"executeCommand('superscript')\"\n            title=\"Superscript\">\n            <i class=\"fa fa-superscript\" aria-hidden=\"true\"></i>\n          </button>\n          <button class=\"ngx-editor-button\" *ngIf=\"canEnableToolbarOptions('subscript')\" (click)=\"executeCommand('subscript')\" title=\"Subscript\">\n            <i class=\"fa fa-subscript\" aria-hidden=\"true\"></i>\n          </button>\n        </div>\n        <div class=\"ngx-toolbar-set\">\n          <button class=\"ngx-editor-button\" *ngIf=\"canEnableToolbarOptions('justifyLeft')\" (click)=\"executeCommand('justifyLeft')\"\n            title=\"Justify Left\">\n            <i class=\"fa fa-align-left\" aria-hidden=\"true\"></i>\n          </button>\n          <button class=\"ngx-editor-button\" *ngIf=\"canEnableToolbarOptions('justifyCenter')\" (click)=\"executeCommand('justifyCenter')\"\n            title=\"Justify Center\">\n            <i class=\"fa fa-align-center\" aria-hidden=\"true\"></i>\n          </button>\n          <button class=\"ngx-editor-button\" *ngIf=\"canEnableToolbarOptions('justifyRight')\" (click)=\"executeCommand('justifyRight')\"\n            title=\"Justify Right\">\n            <i class=\"fa fa-align-right\" aria-hidden=\"true\"></i>\n          </button>\n          <button class=\"ngx-editor-button\" *ngIf=\"canEnableToolbarOptions('justifyFull')\" (click)=\"executeCommand('justifyFull')\"\n            title=\"Justify\">\n            <i class=\"fa fa-align-justify\" aria-hidden=\"true\"></i>\n          </button>\n          <button class=\"ngx-editor-button\" *ngIf=\"canEnableToolbarOptions('indent')\" (click)=\"executeCommand('indent')\" title=\"Indent\">\n            <i class=\"fa fa-indent\" aria-hidden=\"true\"></i>\n          </button>\n          <button class=\"ngx-editor-button\" *ngIf=\"canEnableToolbarOptions('outdent')\" (click)=\"executeCommand('outdent')\" title=\"Outdent\">\n            <i class=\"fa fa-outdent\" aria-hidden=\"true\"></i>\n          </button>\n        </div>\n        <div class=\"ngx-toolbar-set\">\n          <button class=\"ngx-editor-button\" *ngIf=\"canEnableToolbarOptions('cut')\" (click)=\"executeCommand('cut')\" title=\"Cut\">\n            <i class=\"fa fa-scissors\" aria-hidden=\"true\"></i>\n          </button>\n          <button class=\"ngx-editor-button\" *ngIf=\"canEnableToolbarOptions('copy')\" (click)=\"executeCommand('copy')\" title=\"Copy\">\n            <i class=\"fa fa-files-o\" aria-hidden=\"true\"></i>\n          </button>\n          <button class=\"ngx-editor-button\" *ngIf=\"canEnableToolbarOptions('delete')\" (click)=\"executeCommand('delete')\" title=\"Delete\">\n            <i class=\"fa fa-trash\" aria-hidden=\"true\"></i>\n          </button>\n          <button class=\"ngx-editor-button\" *ngIf=\"canEnableToolbarOptions('removeFormat')\" (click)=\"executeCommand('removeFormat')\"\n            title=\"Clear Formatting\">\n            <i class=\"fa fa-eraser\" aria-hidden=\"true\"></i>\n          </button>\n          <button class=\"ngx-editor-button\" *ngIf=\"canEnableToolbarOptions('undo')\" (click)=\"executeCommand('undo')\" title=\"Undo\">\n            <i class=\"fa fa-undo\" aria-hidden=\"true\"></i>\n          </button>\n          <button class=\"ngx-editor-button\" *ngIf=\"canEnableToolbarOptions('redo')\" (click)=\"executeCommand('redo')\" title=\"Redo\">\n            <i class=\"fa fa-repeat\" aria-hidden=\"true\"></i>\n          </button>\n        </div>\n        <div class=\"ngx-toolbar-set\">\n          <button class=\"ngx-editor-button\" *ngIf=\"canEnableToolbarOptions('paragraph')\" (click)=\"executeCommand('insertParagraph')\"\n            title=\"Paragraph\">\n            <i class=\"fa fa-paragraph\" aria-hidden=\"true\"></i>\n          </button>\n          <button class=\"ngx-editor-button\" *ngIf=\"canEnableToolbarOptions('blockquote')\" (click)=\"blockQuote()\" title=\"Blockquote\">\n            <i class=\"fa fa-quote-left\" aria-hidden=\"true\"></i>\n          </button>\n          <button class=\"ngx-editor-button\" *ngIf=\"canEnableToolbarOptions('removeBlockquote')\" (click)=\"removeQuote()\" title=\"Remove Blockquote\">\n            <i class=\"fa fa-quote-right\" aria-hidden=\"true\"></i>\n          </button>\n          <button class=\"ngx-editor-button\" *ngIf=\"canEnableToolbarOptions('horizontalLine')\" (click)=\"executeCommand('insertHorizontalRule')\"\n            title=\"Horizontal Line\">\n            <i class=\"fa fa-minus\" aria-hidden=\"true\"></i>\n          </button>\n          <button class=\"ngx-editor-button\" *ngIf=\"canEnableToolbarOptions('orderedList')\" (click)=\"executeCommand('insertUnorderedList')\"\n            title=\"Unodered List\">\n            <i class=\"fa fa-list-ul\" aria-hidden=\"true\"></i>\n          </button>\n          <button class=\"ngx-editor-button\" *ngIf=\"canEnableToolbarOptions('unorderedList')\" (click)=\"executeCommand('insertOrderedList')\"\n            title=\"Ordered List\">\n            <i class=\"fa fa-list-ol\" aria-hidden=\"true\"></i>\n          </button>\n        </div>\n      </div>\n      <div class=\"ngx-editor-textarea\" [attr.contenteditable]=\"config['editable']\" [attr.placeholder]=\"config['placeholder']\" (input)=\"html = $event.target.innerHTML; htmlContentChange($event.target.innerHTML)\"\n        [attr.translate]=\"config['translate']\" [attr.spellcheck]=\"config['spellcheck']\" [style.height]=\"config['height']\" [style.minHeight]=\"minHeight || config['minHeight']\"\n        [style.resize]=\"canResize()\" #ngxTextArea></div>\n      <app-ngx-grippie *ngIf=\"resizer === 'stack'\"></app-ngx-grippie>\n    </div>\n  ",
                styles: ["\n    /*\n     * editor styles\n     */\n    .ngx-editor {\n      position: relative; }\n      .ngx-editor ::ng-deep [contenteditable=true]:empty:before {\n        content: attr(placeholder);\n        display: block; }\n      .ngx-editor .ngx-toolbar {\n        background-color: #f5f5f5;\n        border-bottom: 1px solid #ddd;\n        font-size: 0.8rem;\n        padding: 0.2rem;\n        border: 1px solid #ddd; }\n        .ngx-editor .ngx-toolbar .ngx-toolbar-set {\n          display: inline-block;\n          border: 1px solid #ddd;\n          border-radius: 5px;\n          background-color: white; }\n          .ngx-editor .ngx-toolbar .ngx-toolbar-set .ngx-editor-button {\n            background-color: #f5f5f5;\n            background-color: transparent;\n            border: 0;\n            padding: 0.4rem;\n            min-width: 2.5rem;\n            float: left;\n            border-right: 1px solid #ddd; }\n            .ngx-editor .ngx-toolbar .ngx-toolbar-set .ngx-editor-button:hover {\n              cursor: pointer;\n              background-color: #e3e3e3;\n              -webkit-transition: 0.5s ease;\n              transition: 0.5s ease; }\n            .ngx-editor .ngx-toolbar .ngx-toolbar-set .ngx-editor-button:focus, .ngx-editor .ngx-toolbar .ngx-toolbar-set .ngx-editor-button.focus {\n              outline: 0; }\n            .ngx-editor .ngx-toolbar .ngx-toolbar-set .ngx-editor-button:last-child {\n              border-right: transparent; }\n      .ngx-editor .ngx-editor-textarea {\n        min-height: 5rem;\n        padding: 0.5rem 0.8rem 1rem 0.8rem;\n        border: 1px solid #ddd;\n        border-top: transparent !important;\n        background-color: #fff;\n        overflow: auto; }\n        .ngx-editor .ngx-editor-textarea:focus, .ngx-editor .ngx-editor-textarea.focus {\n          outline: 0; }\n        .ngx-editor .ngx-editor-textarea ::ng-deep blockquote {\n          margin-left: 1rem;\n          border-left: 0.2em solid #dfe2e5;\n          padding-left: 0.5rem; }\n  "]
            },] },
];
/**
 * @nocollapse
 */
NgxEditorComponent.ctorParameters = function () { return []; };
NgxEditorComponent.propDecorators = {
    'htmlChange': [{ type: core.Output },],
    'textArea': [{ type: core.ViewChild, args: ['ngxTextArea',] },],
    'editable': [{ type: core.Input },],
    'spellcheck': [{ type: core.Input },],
    'placeholder': [{ type: core.Input },],
    'translate': [{ type: core.Input },],
    'height': [{ type: core.Input },],
    'minHeight': [{ type: core.Input },],
    'width': [{ type: core.Input },],
    'minWidth': [{ type: core.Input },],
    'toolbar': [{ type: core.Input },],
    'resizer': [{ type: core.Input },],
    'config': [{ type: core.Input },],
    'html': [{ type: core.Input },],
};
var NgxGrippieComponent = /** @class */ (function () {
    /**
     * @param {?} _editorComponent
     */
    function NgxGrippieComponent(_editorComponent) {
        this._editorComponent = _editorComponent;
        this.oldY = 0;
        this.grabber = false;
    }
    /**
     * @param {?} event
     * @return {?}
     */
    NgxGrippieComponent.prototype.onMouseMove = function (event) {
        if (!this.grabber) {
            return;
        }
        this._editorComponent.resizeTextArea(event.clientY - this.oldY);
        this.oldY = event.clientY;
    };
    /**
     * @param {?} event
     * @return {?}
     */
    NgxGrippieComponent.prototype.onMouseUp = function (event) {
        this.grabber = false;
    };
    /**
     * @param {?} event
     * @param {?=} resizer
     * @return {?}
     */
    NgxGrippieComponent.prototype.onResize = function (event, resizer) {
        this.grabber = true;
        this.oldY = event.clientY;
        event.preventDefault();
    };
    return NgxGrippieComponent;
}());
NgxGrippieComponent.decorators = [
    { type: core.Component, args: [{
                selector: 'app-ngx-grippie',
                template: "\n    <div class=\"ngx-editor-grippie\">\n      <svg xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" style=\"isolation:isolate\" viewBox=\"651.6 235 26 5\"\n        width=\"26\" height=\"5\">\n        <g id=\"sprites\">\n          <path d=\" M 651.6 235 L 653.6 235 L 653.6 237 L 651.6 237 M 654.6 238 L 656.6 238 L 656.6 240 L 654.6 240 M 660.6 238 L 662.6 238 L 662.6 240 L 660.6 240 M 666.6 238 L 668.6 238 L 668.6 240 L 666.6 240 M 672.6 238 L 674.6 238 L 674.6 240 L 672.6 240 M 657.6 235 L 659.6 235 L 659.6 237 L 657.6 237 M 663.6 235 L 665.6 235 L 665.6 237 L 663.6 237 M 669.6 235 L 671.6 235 L 671.6 237 L 669.6 237 M 675.6 235 L 677.6 235 L 677.6 237 L 675.6 237\"\n            fill=\"rgb(147,153,159)\" />\n        </g>\n      </svg>\n    </div>\n  ",
                styles: ["\n    .ngx-editor-grippie {\n      height: 9px;\n      background-color: #f1f1f1;\n      position: relative;\n      text-align: center;\n      cursor: s-resize;\n      border: 1px solid #ddd;\n      border-top: transparent; }\n      .ngx-editor-grippie svg {\n        position: absolute;\n        top: 1.5px; }\n  "]
            },] },
];
/**
 * @nocollapse
 */
NgxGrippieComponent.ctorParameters = function () { return [
    { type: NgxEditorComponent, },
]; };
NgxGrippieComponent.propDecorators = {
    'onMouseMove': [{ type: core.HostListener, args: ['document:mousemove', ['$event'],] },],
    'onMouseUp': [{ type: core.HostListener, args: ['document:mouseup', ['$event'],] },],
    'onResize': [{ type: core.HostListener, args: ['mousedown', ['$event'],] },],
};
var NgxEditorModule = /** @class */ (function () {
    function NgxEditorModule() {
    }
    return NgxEditorModule;
}());
NgxEditorModule.decorators = [
    { type: core.NgModule, args: [{
                imports: [
                    common.CommonModule
                ],
                declarations: [
                    NgxEditorComponent,
                    NgxGrippieComponent
                ],
                exports: [
                    NgxEditorComponent,
                    NgxGrippieComponent
                ]
            },] },
];
/**
 * @nocollapse
 */
NgxEditorModule.ctorParameters = function () { return []; };

exports.NgxEditorModule = NgxEditorModule;
exports.ɵa = NgxEditorComponent;
exports.ɵb = NgxGrippieComponent;

Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=ngx-editor.umd.js.map
